@@ -1198,7 +1198,7 @@ gog_axis_set_property (GObject *obj, guint param_id,
 	case AXIS_PROP_ASSIGNED_FORMAT_STR_XL : {
 		char const *str = g_value_get_string (value);
 		resized = gog_axis_set_format (axis, (str != NULL)
-			? go_format_new_from_XL (str, FALSE)
+			? go_format_new_from_XL (str)
 			: NULL);
 		calc_ticks = resized;
 		break;
@@ -1252,8 +1252,8 @@ gog_axis_get_property (GObject *obj, guint param_id,
 		break;
 	case AXIS_PROP_ASSIGNED_FORMAT_STR_XL :
 		if (axis->assigned_format != NULL)
-			g_value_take_string (value,
-				go_format_as_XL	(axis->assigned_format, FALSE));
+			g_value_set_string (value,
+				go_format_as_XL	(axis->assigned_format));
 		else
 			g_value_set_static_string (value, NULL);
 		break;
@@ -1576,7 +1576,7 @@ cb_polar_unit_changed (GtkComboBox *combo,
 	GOFormat *format;
 
 	axis->polar_unit = gtk_combo_box_get_active (combo);
-	format = go_format_new_from_XL (polar_units[axis->polar_unit].xl_format, FALSE);
+	format = go_format_new_from_XL (polar_units[axis->polar_unit].xl_format);
 
 	if (gog_axis_set_format (axis, format) &&
 	    state->format_selector != NULL) 
@@ -1689,28 +1689,29 @@ gog_axis_populate_editor (GogObject *gobj,
 			     glade_xml_get_widget (gui, "axis_pref_box"),
 			     _("Scale"));
 
-	/* Style page */
-	(GOG_OBJECT_CLASS(parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
+	if (gog_axis_get_atype (axis) < GOG_AXIS_VIRTUAL) {
+	    /* Style page */
+	    (GOG_OBJECT_CLASS(parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
 
-	/* Format page */
-	if (!axis->is_discrete && gog_axis_get_atype (axis) != GOG_AXIS_PSEUDO_3D) {
-		w = go_format_sel_new_full (TRUE);
-		state->format_selector = w;
+	    /* Format page */
+	    if (!axis->is_discrete) {
+		    w = go_format_sel_new_full (TRUE);
+		    state->format_selector = w;
 
-		if (axis->assigned_format != NULL && !go_format_is_general (axis->assigned_format))
-			go_format_sel_set_style_format (GO_FORMAT_SEL (w),
-				axis->assigned_format);
-		else if (axis->format != NULL)
-			go_format_sel_set_style_format (GO_FORMAT_SEL (w),
-				axis->format);
+		    if (axis->assigned_format != NULL && !go_format_is_general (axis->assigned_format))
+			    go_format_sel_set_style_format (GO_FORMAT_SEL (w),
+				    axis->assigned_format);
+		    else if (axis->format != NULL)
+			    go_format_sel_set_style_format (GO_FORMAT_SEL (w),
+				    axis->format);
 
-		gog_editor_add_page (editor, w, _("Format"));
+		    gog_editor_add_page (editor, w, _("Format"));
 
-		gtk_widget_show (w);
-		g_signal_connect (G_OBJECT (w),
-			"format_changed", G_CALLBACK (cb_axis_fmt_changed), axis);
+		    gtk_widget_show (w);
+		    g_signal_connect (G_OBJECT (w),
+			    "format_changed", G_CALLBACK (cb_axis_fmt_changed), axis);
+	    }
 	}
-
 	w = glade_xml_get_widget (gui, "axis_pref_box");
 	g_object_set_data_full (G_OBJECT (w), "state", state,
 				(GDestroyNotify)gog_axis_pref_state_free);
@@ -1759,32 +1760,40 @@ gog_axis_class_init (GObjectClass *gobject_klass)
 
 	/* no need to persist, the role handles that */
 	g_object_class_install_property (gobject_klass, AXIS_PROP_TYPE,
-		g_param_spec_int ("type", "Type",
-			"GogAxisType",
-			GOG_AXIS_UNKNOWN, GOG_AXIS_TYPES, GOG_AXIS_UNKNOWN, G_PARAM_READWRITE));
+		g_param_spec_int ("type", _("Type"),
+			_("Numerical type of this axis"),
+			GOG_AXIS_UNKNOWN, GOG_AXIS_TYPES, GOG_AXIS_UNKNOWN, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_klass, AXIS_PROP_INVERT,
-		g_param_spec_boolean ("invert-axis", NULL,
-			"Scale from high to low rather than low to high",
-			FALSE, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_boolean ("invert-axis", _("Invert axis"),
+			_("Scale from high to low rather than low to high"),
+			FALSE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_PROP_MAP,
-		g_param_spec_string ("map-name", "MapName",
-			"The name of the map for scaling",
-			"linear", G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+		g_param_spec_string ("map-name", _("MapName"),
+			_("The name of the map for scaling"),
+			"linear", 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_PROP_ASSIGNED_FORMAT_STR_XL,
-		g_param_spec_string ("assigned-format-string-XL", NULL,
-			"The user assigned format to use for non-discrete axis labels (XL format)",
-			"General", G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_string ("assigned-format-string-XL", 
+			_("Assigned XL format"),
+			_("The user assigned format to use for non-discrete axis labels (XL format)"),
+			"General", 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_PROP_CIRCULAR_ROTATION,
-		g_param_spec_double ("circular-rotation", "Rotation of circular axis", 
-				     "Rotation of circular axis",
-				     GOG_AXIS_CIRCULAR_ROTATION_MIN, 
-				     GOG_AXIS_CIRCULAR_ROTATION_MAX,
-				     0.0, G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+		g_param_spec_double ("circular-rotation", 
+			_("Rotation of circular axis"), 
+			_("Rotation of circular axis"),
+			GOG_AXIS_CIRCULAR_ROTATION_MIN, 
+			GOG_AXIS_CIRCULAR_ROTATION_MAX,
+			0.0, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_PROP_POLAR_UNIT,
-		g_param_spec_string ("polar-unit", "Polar axis set unit", 
-				     "Polar axis set unit", 
-				     polar_units[GOG_AXIS_POLAR_UNIT_DEGREES].name,
-				     G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+		g_param_spec_string ("polar-unit", 
+			_("Polar axis set unit"), 
+			_("Polar axis set unit"), 
+			polar_units[GOG_AXIS_POLAR_UNIT_DEGREES].name,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
 
