@@ -32,6 +32,7 @@
 #include <goffice/utils/go-line.h>
 #include <goffice/utils/go-pattern.h>
 #include <glib-object.h>
+#include <cairo.h>
 
 G_BEGIN_DECLS
 
@@ -48,6 +49,8 @@ typedef enum {
 	GOG_STYLE_MARKER	= 1 << 3,
 	GOG_STYLE_FONT		= 1 << 4,
 	GOG_STYLE_TEXT_LAYOUT	= 1 << 5,
+	GOG_STYLE_INTERPOLATION	= 1 << 6,
+	GOG_STYLE_MARKER_NO_COLOR	= 1 << 7,
 	GOG_STYLE_ALL		= 0x1F
 } GogStyleFlag;
 
@@ -90,6 +93,10 @@ struct _GogStyle {
 	GogStyleFlag	disable_theming;
 
 	GogStyleLine	outline, line;
+	struct {
+		GOLineInterpolation type;
+		gboolean 	 auto_type;
+	} interpolation;
 	struct {
 		GogFillStyle	type;
 		gboolean	auto_fore, auto_back;	/* share between pattern and gradient */
@@ -103,7 +110,7 @@ struct _GogStyle {
 		} gradient;
 		struct {
 			GogImageType	 type;
-			gpointer	 image;
+			GOImage	 *image;
 			char		*filename;
 		} image;
 	} fill;
@@ -151,6 +158,9 @@ gpointer   gog_style_get_editor	     	(GogStyle *style,
 					 GOCmdContext *cc,
 					 GObject *object_with_style);
 
+cairo_pattern_t *gog_style_create_cairo_pattern (GogStyle const *style,
+						 double width, double height, gpointer *data);
+
 G_END_DECLS
 
 #endif /* GO_GRAPH_STYLE_H */
